#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='grope',
    version='0.1',

    description='Generalized rope data structure',
    author='Martin Vejnár',
    author_email='vejnar.martin@gmail.com',
    url='https://github.com/avakar/grope',
    license='MIT',

    packages=['grope'],
    )
